import {
  select,
  csv, 
  scaleLinear,
  scaleTime,
  extent,
  max,
  axisLeft,
  axisBottom,
  area,
  curveBasis,
  format
} from 'd3';
import { getData } from './data';

// Get the SVG from the DOM
const svg = select('svg');

// Extract Width and Height from SVG and parse it to float
const height = +svg.attr('height');
const width  = +svg.attr('width');
const margin = {top: 65, right: 45, bottom: 90, left: 115};
const innerWidth = width-margin.left-margin.right;
const innerHeight = height-margin.top-margin.bottom;

const render = data => {
  const xValue = d => d.year;
  const xAxisLabel = 'Year';
  
  const yValue = d => d.population;
  const yAxisLabel = 'Population';

  const titleLabel = `${xAxisLabel} versus ${yAxisLabel}`;

  const circleRadius = 5;
  // Set Scales of X and Y Axis
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0,innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain([0,max(data, yValue)])
  	.range([innerHeight,0])
  	.nice();
  
  // Format X Axis
  const xAxis = axisBottom(xScale)
  	.ticks(6)
  	.tickSize(-innerHeight)
  	.tickPadding(20);
  
  // Format Y Axis
  const yAxisTickFormat = number =>
  	format('.1s')(number)
  		.replace('G','B');
           
  const yAxis = axisLeft(yScale)
  	.tickFormat(yAxisTickFormat)
  	.tickSize(-innerWidth)
  	.tickPadding(10);

  // Add Main Bar Group
  const barGroup = svg
  	.append('g')
  		.attr('transform', `translate(${margin.left}, ${margin.top})`);

  // Generate the Area Path
  const areaGenerator = area()
  	.x(d => xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d => yScale(yValue(d)))
  	.curve(curveBasis);
  
  // Add The Path
  barGroup
  	.append('path')
  		.attr('class','line-path')
  		.attr('d',areaGenerator(data));
  
  // Add Y Axis Group
  const yAxisGroup = barGroup
    .append('g')
    	.call(yAxis);
  yAxisGroup
			.select('.domain')
    		.remove();
  yAxisGroup
    .append('text')
  		.attr('class','axisLabel')
  		.attr('x',-(innerHeight/2))
  		.attr('y',-60)
  		.attr('transform', 'rotate(-90)')
  		.attr('fill', 'black')
    	.attr('text-anchor', 'middle')
  		.text(yAxisLabel);
  
  // Add X Axis Group
  const xAxisGroup = barGroup
    .append('g')
    	.call(xAxis)
  		.attr('transform', `translate(0, ${innerHeight})`);
 	xAxisGroup
   .select('.domain')
  		.remove();
 	xAxisGroup
    .append('text')
  		.attr('class','axisLabel')
  		.attr('x',innerWidth/2)
  		.attr('y',margin.bottom-10)
  		.attr('fill', 'black')
  		.text(xAxisLabel);

  // Add The Title
  barGroup.append('text')
		.attr('class','titleLabel')
  	.attr('x',innerWidth/2)
  	.attr('y', -20)
  	.attr('text-anchor', 'middle')
  	.text(titleLabel);

};

getData()
  .then(data => {
//  	console.log(data);
  	render(data);
});

